==> elgg-1.9.2.zip: elgg-1.9.2/mod/developers/views/default/theme_sandbox/buttons.php <==
<table class="theme-sandbox-table">
	<thead>
		<tr>
			<th>Anchor links</th>
			<th>Default</th>
			<th>Disabled (.elgg-state-disabled)</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<th>Base (.elgg-button)</th>
			<td><a href="#" class="elgg-button">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Action (.elgg-button-action)</th>
			<td><a href="#" class="elgg-button elgg-button-action">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-action elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Cancel (.elgg-button-cancel)</th>
			<td><a href="#" class="elgg-button elgg-button-cancel">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-cancel elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Submit (.elgg-button-submit)</th>
			<td><a href="#" class="elgg-button elgg-button-submit">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-submit elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Special (.elgg-button-special)</th>
			<td><a href="#" class="elgg-button elgg-button-special">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-special elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Delete (.elgg-button-delete)</th>
			<td><a href="#" class="elgg-button elgg-button-delete">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-delete elgg-state-disabled">anchor</a></td>
		</tr>
	</tbody>
</table>

<table class="theme-sandbox-table mtl">
	<thead>
		<tr>
			<th>Input type="submit"</th>
			<th>Default</th>
			<th>Disabled (.elgg-state-disabled)</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<th>Base (.elgg-button)</th>
			<td><input type="submit" class="elgg-button" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-state-disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Action (.elgg-button-action)</th>
			<td><input type="submit" class="elgg-button elgg-button-action" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-action elgg-state-disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Cancel (.elgg-button-cancel)</th>
			<td><input type="submit" class="elgg-button elgg-button-cancel" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-cancel elgg-state-disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Submit (.elgg-button-submit)</th>
			<td><input type="submit" class="elgg-button elgg-button-submit" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-submit elgg-state-disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Special (.elgg-button-special)</th>
			<td><input type="submit" class="elgg-button elgg-button-special" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-special elgg-state-disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Delete (.elgg-button-delete)</th>
			<td><input type="submit" class="elgg-button elgg-button-delete" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-delete elgg-state-disabled" value="submit" /></td>
		</tr>
	</tbody>
</table>

==> elgg-3.0.5.zip: elgg-3.0.5/mod/developers/views/default/theme_sandbox/buttons.php <==
<table class="elgg-table">
	<thead>
		<tr>
			<th>Anchor links</th>
			<th>Default</th>
			<th>Disabled (.elgg-state-disabled)</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<th>Base (.elgg-button)</th>
			<td><a href="#" class="elgg-button">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Action (.elgg-button-action)</th>
			<td><a href="#" class="elgg-button elgg-button-action">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-action elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Cancel (.elgg-button-cancel)</th>
			<td><a href="#" class="elgg-button elgg-button-cancel">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-cancel elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Submit (.elgg-button-submit)</th>
			<td><a href="#" class="elgg-button elgg-button-submit">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-submit elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Special (.elgg-button-special)</th>
			<td><a href="#" class="elgg-button elgg-button-special">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-special elgg-state-disabled">anchor</a></td>
		</tr>
		<tr>
			<th>Delete (.elgg-button-delete)</th>
			<td><a href="#" class="elgg-button elgg-button-delete">anchor</a></td>
			<td><a href="#" class="elgg-button elgg-button-delete elgg-state-disabled">anchor</a></td>
		</tr>
	</tbody>
</table>

<table class="elgg-table mtl">
	<thead>
		<tr>
			<th>Input type="submit"</th>
			<th>Default</th>
			<th>Disabled (.elgg-state-disabled)</th>
			<th>Disabled [attribute disabled=true]</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<th>Base (.elgg-button)</th>
			<td><input type="submit" class="elgg-button" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-state-disabled" value="submit" /></td>
			<td><input type="submit" class="elgg-button" disabled="disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Action (.elgg-button-action)</th>
			<td><input type="submit" class="elgg-button elgg-button-action" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-action elgg-state-disabled" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-action" disabled="disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Cancel (.elgg-button-cancel)</th>
			<td><input type="submit" class="elgg-button elgg-button-cancel" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-cancel elgg-state-disabled" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-cancel" disabled="disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Submit (.elgg-button-submit)</th>
			<td><input type="submit" class="elgg-button elgg-button-submit" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-submit elgg-state-disabled" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-submit" disabled="disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Special (.elgg-button-special)</th>
			<td><input type="submit" class="elgg-button elgg-button-special" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-special elgg-state-disabled" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-special" disabled="disabled" value="submit" /></td>
		</tr>
		<tr>
			<th>Delete (.elgg-button-delete)</th>
			<td><input type="submit" class="elgg-button elgg-button-delete" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-delete elgg-state-disabled" value="submit" /></td>
			<td><input type="submit" class="elgg-button elgg-button-delete" disabled="disabled" value="submit" /></td>
		</tr>
	</tbody>
</table>
